==> vokoscreen_2.4.0.orig.tar.gz: vokoscreen-2.4.0/language/vokoscreen_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>El dispositivo está ocupado</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Utilizado por</translation>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Enviar último video por correo</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Enviar uno o más vídeos seleccionados</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>Por favor, instale un reproductor de vídeo</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Encontrará el vídeo como un archivo adjunto</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Seleccione uno o más archivos</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Borde</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>Mostrar en pantalla completa</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User-defined</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>El dispositivo está ocupado</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Utilizado por</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliación</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Sonido</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Códec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>No grabar el puntero del ratón</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Ruta del vídeo</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Minimizar Vokoscreen al iniciar la grabación</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Tiempo de grabación</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Tamaño en kB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>screensize grabación</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Configuración de fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Abrir directorio</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Cuenta regresiva</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Reproducir último vídeo</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Enviar vídeo</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Cuadros por segundo actuales</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Ir</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Sitio web</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Asistencia</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Desarrollador</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Fotogramas</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Programa para grabar</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traducciones</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Código fuente</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostrar en bandeja del sistema</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Nueva versión disponible</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Códec de video</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Códec de audio</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Cámara web</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Seleccionar cámara web</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>Reflejo</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Pantalla</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>Todas las pantallas</translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>Página del desarrollador</translation>
    </message>
</context>
</TS>

==> vokoscreen_2.5.0.orig.tar.gz: vokoscreen-2.5.0/language/vokoscreen_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>El dispositivo está ocupado</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Utilizado por</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Show Click Settings</source>
        <translation>Mostrar configuraciones de Click</translation>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Enviar último video por correo</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Enviar uno o más vídeos seleccionados</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>Por favor, instale un reproductor de vídeo</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Encontrará el vídeo como un archivo adjunto</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Seleccione uno o más archivos</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>double-click to maximize</source>
        <translation>Doble click para maximizar</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Borde</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>Mostrar en pantalla completa</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation>Clic derecho para menú</translation>
    </message>
    <message>
        <source>User-defined</source>
        <translation>Definido por el usuario</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>El dispositivo está ocupado</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Utilizado por</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>double-click to maximize</source>
        <translation>Doble click para maximizar</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliación</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Sonido</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Códec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>No grabar el puntero del ratón</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Ruta del vídeo</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Minimizar Vokoscreen al iniciar la grabación</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Tiempo de grabación</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Tamaño en kB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>screensize grabación</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Configuración de fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Abrir directorio</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Cuenta regresiva</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Reproducir último vídeo</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Enviar vídeo</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Cuadros por segundo actuales</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Ir</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Sitio web</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Asistencia</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Desarrollador</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Fotogramas</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traducciones</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Código fuente</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostrar en bandeja del sistema</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Nueva versión disponible</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Códec de video</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Códec de audio</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Cámara web</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Seleccionar cámara web</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>Reflejo</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Pantalla</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>Todas las pantallas</translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>Página del desarrollador</translation>
    </message>
    <message>
        <source>Recorder</source>
        <translation>Capturadora</translation>
    </message>
    <message>
        <source>Select recorder</source>
        <translation>Seleccionar capturadora</translation>
    </message>
    <message>
        <source>Hide window</source>
        <translation>Esconder ventana</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Show window</source>
        <translation>Mostrar ventana</translation>
    </message>
    <message>
        <source>Lossless</source>
        <translation>Sin pérdidas</translation>
    </message>
</context>
</TS>
